helga-mail
===========

Cause sometimes bouncers aren't enough, or reliable. For those times
when we want to send a message to another user before we forget,
here's helga-mail.::

  <bigjust> ,mail justin Hey Buddy, welcome back from your trip!
  <helga> message saved for justin.

  Later...

  *justin joins*
  <helga> justin, message from bigjust: Hey Buddy, welcome back from
  your trip!
  <justin> dawwww


License
-------

Copyright (c) 2017 Justin Caratzas

GPLv3 Licensed
